import type {
    FoundationFormErrors,
    FoundationFormErrorsLegacy,
    FoundationFormErrorsLegacyLegacy,
} from '../types';

import getErrorItems from './getErrorItems';


function testpgettext(context: string, key: string): string {
    return `${context}:${key}`;
}

function testformatKey(context: string, key: string): string {
    const ctx = key === '__all__'
        ? 'generic-error-field'
        : context;

    return testpgettext(ctx, key);
}

test('legacy-legacy', () => {
    const errors: FoundationFormErrorsLegacyLegacy = 'message';
    const result = getErrorItems(errors, 'ctx', testformatKey, 'context', testpgettext);
    expect(result).toEqual(['message']);
});

test('object (empty)', () => {
    const errors: FoundationFormErrorsLegacy = {
        'key': [],
    };

    const result = getErrorItems(errors, 'ctx', testformatKey, 'context', testpgettext);
    expect(result).toEqual([]);
});

test('object (implicit legacy)', () => {
    const errors: FoundationFormErrorsLegacy = {
        'key': ['message'],
    };

    const result = getErrorItems(errors, 'ctx', testformatKey, 'context', testpgettext);
    expect(result).toEqual(['form field error field:key: action-form-errors:message']);
});

test('object (explicit legacy)', () => {
    const errors: FoundationFormErrors = {
        'key': [
            ['message-ctx', 'message'],
        ],
    };

    const result = getErrorItems(errors, 'ctx', testformatKey, 'legacy', testpgettext);
    expect(result).toEqual(['form field error field:key: action-form-errors:message-ctx,message']);
});

test('object (context)', () => {
    const errors: FoundationFormErrors = {
        'key': [
            ['message-ctx', 'message'],
        ],
    };

    const result = getErrorItems(errors, 'ctx', testformatKey, 'context', testpgettext);
    expect(result).toEqual(['ctx:key: message-ctx:message']);
});
